@@ -1,7 +1,6 @@
 /*
  * Copyright (C) 1993-2006 Robert & Jeremy Laine
- * 
- * $Id: disparea.h,v 1.7 2006/01/28 12:32:54 jeremy_laine Exp $
+ * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +20,7 @@
 #ifndef DISPAREA_H
 #define DISPAREA_H
 
-#include "geocpp/vect_geom.h"
+#include "geocpp/geometry.h"
 
 
 /** A generic display area
