@@ -1,9 +1,7 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Lain
+ * Copyright (C) 1993-2006 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
- * $Id: filewriter.h,v 1.6 2006/01/25 21:54:00 jeremy_laine Exp $
- * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -32,12 +30,11 @@ class CFileWriter : public CFileIO
 public:
     /** The constructor.
      *
-     * @param name the object's name
      * @param ext the file extension
      * @param desc description of the file type
      */
-    CFileWriter(const QString &name, const QString &ext, const QString &desc)
-            : CFileIO(name, ext, desc)
+    CFileWriter(const QString &ext, const QString &desc)
+            : CFileIO(ext, desc)
     {}
     ;
 
