@@ -1,7 +1,6 @@
 /*
  * Copyright (C) 1993-2006 Robert & Jeremy Laine
- *
- * $Id: formdef.cpp,v 1.79 2006/01/25 21:54:00 jeremy_laine Exp $
+ * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -351,19 +350,19 @@ bool CFormDef::check()
 
     L1 = (long)(saildef->LOA);
 
-    if (saildef->foreJ > 0.8* L1)
+    if (saildef->foreJ > 0.9* L1)
     {
         flag = false;
         txtTriangBase->setPalette(palHi);
         txtLOA->setPalette(palRel);
-        saildef->foreJ = floor(0.8*L1);
+        saildef->foreJ = floor(0.9*L1);
     }
-    else   if (saildef->foreJ < 0.1* L1)
+    else   if (saildef->foreJ < 0.05* L1)
     {
         flag = false;
         txtTriangBase->setPalette(palLo);
         txtLOA->setPalette(palRel);
-        saildef->foreJ = ceil(0.1*L1);
+        saildef->foreJ = ceil(0.05*L1);
     }
     else
     {
@@ -381,12 +380,12 @@ bool CFormDef::check()
         txtLOA->setPalette(palRel);
         saildef->foreI = 3*L1;
     }
-    else if (saildef->foreI < 0.3*L1)
+    else if (saildef->foreI < 0.1*L1)
     {
         flag = false;
         txtTriangHoist->setPalette(palLo);
         txtLOA->setPalette(palRel);
-        saildef->foreI = ceil( 0.3*L1);
+        saildef->foreI = ceil( 0.1*L1);
     }
     else
     {
@@ -399,12 +398,12 @@ bool CFormDef::check()
     L1 = (long)(saildef->LOA);
 
     saildef->tackX  = txtTackDist->text().toDouble();
-    if (saildef->tackX > 0.8*L1)
+    if (saildef->tackX > 0.9*L1)
     {
         flag = false;
         txtTackDist->setPalette(palHi);
         txtLOA->setPalette(palRel);
-        saildef->tackX = floor(0.8*L1);
+        saildef->tackX = floor(0.9*L1);
     }
     else
     {
@@ -417,12 +416,12 @@ bool CFormDef::check()
     L1 = (long)(saildef->foreI);
 
     saildef->tackY  = txtTackHeight->text().toDouble();
-    if (saildef->tackY > 0.3*L1)
+    if (saildef->tackY > 0.5*L1)
     {
         flag = false;
         txtTackHeight->setPalette(palHi);
         txtTriangHoist->setPalette(palRel);
-        saildef->tackY = floor(0.3*L1);
+        saildef->tackY = floor(0.5*L1);
     }
     else
     {
@@ -512,12 +511,12 @@ bool CFormDef::check()
             txtLuffLen->setPalette(palHi);
             saildef->luffL = 3*L1;
         }
-        else if (saildef->luffL < 0.3*L1)
+        else if (saildef->luffL < 0.1*L1)
         {
             flag=false;
             txtTriangHoist->setPalette(palRel);
             txtLuffLen->setPalette(palLo);
-            saildef->luffL = 1 + 0.3*L1;
+            saildef->luffL = 1 + 0.1*L1;
         }
         else
         {
@@ -526,7 +525,7 @@ bool CFormDef::check()
         }
         txtLuffLen->setText(QString::number(saildef->luffL));
 
-        L2 =(long) ((saildef->luffL )/ 10); // luff round limit
+        L2 =(long) ((saildef->luffL ) / 10); // luff round limit
 
         if (saildef->luffR > L2)
         {
@@ -534,11 +533,11 @@ bool CFormDef::check()
             txtLuffRound->setPalette(palHi);
             saildef->luffR = L2;
         }
-        else if (saildef->luffR <0)
+        else if (saildef->luffR <- L2  )
         {
             flag=false;
             txtLuffRound->setPalette(palLo);
-            saildef->luffR = 0;
+            saildef->luffR = - L2 ;
         }
         else
         {
@@ -548,7 +547,7 @@ bool CFormDef::check()
 
         // check main sail gaff length
         L1 =(long) (5);
-        L2 =(long) (3 * saildef->luffL);
+        L2 =(long) (6 * saildef->luffL);
 
         if (saildef->gaffL < L1)
         {
@@ -601,11 +600,11 @@ bool CFormDef::check()
             txtLuffLen->setPalette(palHi);
             saildef->luffL = int (L1);
         }
-        else if (saildef->luffL < L1/10)
+        else if (saildef->luffL < (L1 / 10) )
         {
             flag=false;
             txtLuffLen->setPalette(palLo);
-            saildef->luffL = int(1+real(L1)/10);
+            saildef->luffL = int(1 + real(L1) / 10);
         }
         else
         {
@@ -637,7 +636,7 @@ bool CFormDef::check()
 
         /// check jib gaff length
         L1 =(long) (1);
-        L2 =(long) (70);
+        L2 =(long) (100);
 
         if (saildef->gaffL < L1)
         {
@@ -709,12 +708,12 @@ bool CFormDef::check()
     L1 = (long) saildef->luffL;
     L1 = L1 + (long) saildef->gaffL;
 
-    if (saildef->leechL > 1.4*L1)
+    if (saildef->leechL > 1.5*L1)
     {
         flag = false;
         txtLuffLen->setPalette(palRel);
         txtLeechLen->setPalette(palHi);
-        saildef->leechL = 1.4*L1 -1;
+        saildef->leechL = 1.5*L1 -1;
     }
     else if (saildef->leechL < 0.5*L1)
     {
@@ -767,12 +766,12 @@ bool CFormDef::check()
         break;
     }
 
-    if (saildef->footL > saildef->leechL)
+    if (saildef->footL > 1.5*(saildef->leechL) )
     {
         flag=false;
         txtLeechLen->setPalette( palRel );
         txtFootLen->setPalette( palHi );
-        saildef->footL = saildef->leechL -1;
+        saildef->footL = 1.5*(saildef->leechL) -1;
     }
     else if (saildef->footL < L2)
     {
