@@ -1,7 +1,6 @@
 /*
  * Copyright (C) 1993-2006 Robert & Jeremy Laine
- * 
- * $Id: formhelp.h,v 1.10 2006/01/25 21:54:00 jeremy_laine Exp $
+ * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,16 +23,17 @@
 #include <qdialog.h>
 
 class QTextBrowser;
+class QUrl;
 class CPrefs;
 
-/** Dialog to display the Sailcut Handbook.
+/** Dialog to display the Sailcut CAD Handbook.
   */
 class CFormHelp : public QDialog
 {
     Q_OBJECT
 
 public:
-    CFormHelp(QWidget *parent, CPrefs *pref, const QString& handbook);
+    CFormHelp(QWidget *parent, CPrefs *pref, const QUrl& handbook);
 
 protected:
     void closeEvent( QCloseEvent * e);
