@@ -1,7 +1,6 @@
 /*
  * Copyright (C) 1993-2006 Robert & Jeremy Laine
- *
- * $Id: formmain.cpp,v 1.145 2006/01/28 16:04:02 jeremy_laine Exp $
+ * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,6 +51,9 @@
 #include <QPainter>
 #include <QPrintDialog>
 #include <QPrinter>
+#ifdef HAVE_QDESKTOPSERVICES
+#include <QDesktopServices>
+#endif
 
 
 /**
@@ -68,7 +70,7 @@ CFormMain::CFormMain(CSailApp *myApp, QWidget *parent)
     // locate Handbook
     app->loadTranslation(prefs->language);
     handbook = app->findHandbook(prefs->language);
-    qDebug("handbook : %s", (const char*)handbook.toLocal8Bit());
+    qDebug("handbook : %s", (const char*)handbook.toString().toLocal8Bit());
 
     // create status bar
     statusbar = new QStatusBar(this);
@@ -180,9 +182,9 @@ void CFormMain::languageChange()
 
     // Help menu
     menuHelp->setTitle( tr("&Help") );
-    actionHandbook->setText( tr("Sailcut &Handbook") );
+    actionHandbook->setText( tr("Sailcut CAD &Handbook") );
     actionAboutQt->setText( tr("About &Qt") );
-    actionAbout->setText( tr("About &Sailcut") );
+    actionAbout->setText( tr("About &Sailcut CAD") );
 
     // send changeLanguage to the tabs
     for (unsigned int i = 0; i < panel.size(); i++)
@@ -316,9 +318,9 @@ void CFormMain::setupMenuBar()
     menuLanguage->addAction( "Dansk", this, SLOT( slotLanguage() ) )->setData("dk");
     // menuLanguage->addAction( "Svenska", this, SLOT( slotLanguage() ) )->setData("sv");
     menuLanguage->addAction( QString::fromUtf8("Portugês"), this, SLOT( slotLanguage() ) )->setData("pt");
-    // menuLanguage->addAction( QString::fromUtf8("Español"), this, SLOT( slotLanguage() ) )->setData("es");
+    // menuLanguage->addAction( "Español", this, SLOT( slotLanguage() ) )->setData("es");
     menuLanguage->addAction( "Russian", this, SLOT( slotLanguage() ) )->setData("ru");
-
+    //menuLanguage->addAction( "Polish", this, SLOT( slotLanguage() ) )->setData("pl");
 
     // Help menu
     menuHelp = menuBar()->addMenu("");
@@ -385,11 +387,11 @@ void CFormMain::show(const QString newname)
 
 
 /**
- * Displays the "About Sailcut" dialog box
+ * Displays the "About Sailcut CAD" dialog box
  */
 void CFormMain::slotAbout()
 {
-    QMessageBox::about( this, tr("About Sailcut"),
+    QMessageBox::about( this, tr("About Sailcut CAD"),
 
                         "<h2>Sailcut CAD"
 #ifdef VERSION
@@ -507,7 +509,7 @@ void CFormMain::slotExportFlatDXFBlocks()
  */
 void CFormMain::slotExportFlatHand()
 {
-    CSailWriterHand(flatsail).writeDialog();
+    CSailHandWriter(flatsail).writeDialog();
 }
 
 
@@ -537,6 +539,10 @@ void CFormMain::slotHandbook()
     //qDebug("handbook : %s", (const char*)handbook.toLocal8Bit());
     if ( !handbook.isEmpty() )
     {
+#ifdef HAVE_QDESKTOPSERVICES
+        if (QDesktopServices::openUrl(handbook))
+            return;
+#endif
         CFormHelp(this , prefs , handbook).exec();
     }
 }
