@@ -1,9 +1,7 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Lain
+ * Copyright (C) 1993-2006 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
- * $Id: formmould.h,v 1.18 2006/01/25 21:54:00 jeremy_laine Exp $
- * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -37,19 +35,15 @@ class CSailMould;
  */
 class CFormMould : public QDialog
 {
+    Q_OBJECT
+
 public:
     CFormMould( QWidget* , CSailMould* );
-    /** The destructor */
-    ~CFormMould()
-    {}
-    ;
 
 protected:
     /** the CSailMould */
     CSailMould *sailmould;
 
-    /** Help button */
-    QPushButton* buttonHelp;
     /** OK button */
     QPushButton* buttonOk;
     /** Cancel button */
