@@ -1,7 +1,6 @@
 /*
  * Copyright (C) 1993-2006 Robert & Jeremy Laine
- *
- * $Id: panel.cpp,v 1.1 2006/02/01 19:41:14 jeremy_laine Exp $
+ * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -289,7 +288,7 @@ CPanel CPanel::develop(enumDevelopAlign align) const
     /** develop body of panel by zig-zag triangulation */
     // reset baseline vector for lower right point
     v= CVector3d(flatpanel.bottom.point[1]-flatpanel.top.point[1]);
-    c= CVector3d(v).norm();
+    c= v.norm();
 
     for ( i = 1; i < npb-2; i++ )
     {
@@ -481,8 +480,8 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
     // the panel will have hems added to its edges
     hasHems = true;
 
-    CPoint3d pt = CPoint3d(0,0,0);
-    CVector3d v = CVector3d(0,0,0);
+    CPoint3d pt(0,0,0);
+    CVector3d v(0,0,0);
     CVector3d v0;
     CSubSpace l1, l2;
     real dw;
@@ -664,8 +663,8 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
     {
         // bottom left
         v = CVector3d(cutBottom.point[1]-cutBottom.point[0]);
-        l1 = CSubSpace(cutBottom.point[0],v.matrix(),GEOCPP_FROM_BASE);
-        l2 = CSubSpace(cutLeft.point[0],v1.matrix(),GEOCPP_FROM_BASE);
+        l1 = CSubSpace3d::line(cutBottom.point[0], v);
+        l2 = CSubSpace3d::line(cutLeft.point[0], v1);
 
         /* Compute the lower left intersection point of the cut edges */
         pt = l1.intersect(l2).getp();
@@ -680,32 +679,29 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
         for (i = 0; i < npl-1; i++)
         {
             if ( (CVector3d(cutLeft.point[i] - pt) * v1) <= 0)
-                CVector3d(cutLeft.point[i]) = pt;
+                cutLeft.point[i] = pt;
 
             if ( (CVector3d(cutBottom.point[i] - pt) * v5) <= 0)
-                CVector3d(cutBottom.point[i]) = pt;
+                cutBottom.point[i] = pt;
         }
 
         // lower right
         v = CVector3d(cutBottom.point[npb-1] - cutBottom.point[npb-2]);
-        l1 = CSubSpace(cutBottom.point[npb-1], v.matrix(), GEOCPP_FROM_BASE);
+        l1 = CSubSpace3d::line(cutBottom.point[npb-1], v);
         if (v3.norm() > .01)
         {
             v = CVector3d(cutRight.point[1] - cutRight.point[0]);
-            l2 = CSubSpace(cutRight.point[0], v.matrix(), GEOCPP_FROM_BASE);
+            l2 = CSubSpace3d::line(cutRight.point[0], v);
         }
         else if ( v4.norm() > .01)
         {
             v = CVector3d(cutRight.point[npl/2+1] - cutRight.point[npl/2]);
-            l2 = CSubSpace(cutRight.point[npl/2], v.matrix(), GEOCPP_FROM_BASE);
+            l2 = CSubSpace3d::line(cutRight.point[npl/2], v);
         }
-        else
+        else if ( v6.norm() > .1)
         {
-            if ( v6.norm() > .1)
-            {
-                v = CVector3d(cutTop.point[npb-1] - cutTop.point[npb-2]);
-                l2 = CSubSpace(cutTop.point[npb-1], v.matrix(), GEOCPP_FROM_BASE);
-            }
+            v = CVector3d(cutTop.point[npb-1] - cutTop.point[npb-2]);
+            l2 = CSubSpace3d::line(cutTop.point[npb-1], v);
         }
 
         /* Compute the intersection point of the cut edges */
@@ -724,10 +720,10 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
         for ( i = 1; i < npl/2; i++)
         {
             if ( (CVector3d(cutRight.point[i] - pt) * v3) <= 0 )
-                CVector3d(cutRight.point[i]) = pt;
+                cutRight.point[i] = pt;
 
             if ( (CVector3d(cutBottom.point[npb-1-i] - pt) * v5) >= 0)
-                CVector3d(cutBottom.point[npb-1-i]) = pt;
+                cutBottom.point[npb-1-i] = pt;
         }
     }
     else
@@ -735,23 +731,23 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
         if ( v1.norm() > .01)
         {
             v = CVector3d(cutLeft.point[1] - cutLeft.point[0]);
-            l1 = CSubSpace(cutLeft.point[0], v.matrix(), GEOCPP_FROM_BASE);
+            l1 = CSubSpace3d::line(cutLeft.point[0], v);
         }
         else if ( v2.norm() > .01)
         {
             v = CVector3d(cutLeft.point[npl/2+1] - cutLeft.point[npl/2]);
-            l1 = CSubSpace(cutLeft.point[npl/2], v.matrix(), GEOCPP_FROM_BASE);
+            l1 = CSubSpace3d::line(cutLeft.point[npl/2], v);
         }
 
         if ( v3.norm() > .01)
         {
             v = CVector3d(cutRight.point[1] - cutRight.point[0]);
-            l2 = CSubSpace(cutRight.point[0], v.matrix(), GEOCPP_FROM_BASE);
+            l2 = CSubSpace3d::line(cutRight.point[0], v);
         }
         else if ( v4.norm() > .01)
         {
             v = CVector3d(cutRight.point[npl/2+1] - cutRight.point[npl/2]);
-            l2 = CSubSpace(cutRight.point[npl/2], v.matrix(), GEOCPP_FROM_BASE);
+            l2 = CSubSpace3d::line(cutRight.point[npl/2], v);
         }
 
         /* Compute the intersection point of the 2 side edges */
@@ -769,7 +765,7 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
                                                 * that they are not on the wrong side of the intersect point pt
                                                                                   */
             if ( (CVector3d(cutLeft.point[i] - pt) * v1) <= 0)
-                CVector3d(cutLeft.point[i]) = pt;
+                cutLeft.point[i] = pt;
         }
 
         /* Adjust the lower right point to be at intersection */
@@ -780,7 +776,7 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
         for ( i = 1; i < npl/2; i++)
         {
             if ( (CVector3d(cutRight.point[i] - pt) * v3) <= 0)
-                CVector3d(cutRight.point[i]) = pt;
+                cutRight.point[i] = pt;
         }
     } // end else bottom is a point
 
@@ -790,8 +786,8 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
     {
         // upper left
         v = CVector3d(cutTop.point[1]-cutTop.point[0]);
-        l1 = CSubSpace(cutTop.point[0],v.matrix(),GEOCPP_FROM_BASE);
-        l2 = CSubSpace(cutLeft.point[npl-1],v2.matrix(),GEOCPP_FROM_BASE);
+        l1 = CSubSpace3d::line(cutTop.point[0], v);
+        l2 = CSubSpace3d::line(cutLeft.point[npl-1], v2);
 
         /* Compute the intersection point of the cut edges */
         pt = l1.intersect(l2).getp();
@@ -806,32 +802,29 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
         for ( i = 0 ; i < npl -1 ; i++)
         {
             if ( (CVector3d(cutLeft.point[npl-1-i] - pt) * v2) >= 0)
-                CVector3d(cutLeft.point[npl-1-i]) = pt;
+                cutLeft.point[npl-1-i] = pt;
 
             if ( (CVector3d(cutTop.point[i] - pt) * v6) <= 0)
-                CVector3d(cutTop.point[i]) = pt;
+                cutTop.point[i] = pt;
         }
 
         // upper right
         v = CVector3d(cutTop.point[npb-1] - cutTop.point[npb-2]);
-        l1 = CSubSpace(cutTop.point[npb-1], v.matrix(), GEOCPP_FROM_BASE);
+        l1 = CSubSpace3d::line(cutTop.point[npb-1], v);
         if ( v4.norm() > .01)
         {
             v = CVector3d(cutRight.point[npl-1] - cutRight.point[npl-2]);
-            l2 = CSubSpace(cutRight.point[npl-1], v.matrix(), GEOCPP_FROM_BASE);
+            l2 = CSubSpace3d::line(cutRight.point[npl-1], v);
         }
         else if ( v3.norm() > .01)
         {
             v = CVector3d(cutRight.point[npl/2] - cutRight.point[npl/2-1]);
-            l2 = CSubSpace(cutRight.point[npl/2], v.matrix(), GEOCPP_FROM_BASE);
+            l2 = CSubSpace3d::line(cutRight.point[npl/2], v);
         }
-        else
+        else if ( v5.norm() > .1)
         {
-            if ( v5.norm() > .1)
-            {
-                v = CVector3d(cutBottom.point[npb-1] - cutBottom.point[npb-2]);
-                l2 = CSubSpace(cutBottom.point[npb-1], v.matrix(), GEOCPP_FROM_BASE);
-            }
+            v = CVector3d(cutBottom.point[npb-1] - cutBottom.point[npb-2]);
+            l2 = CSubSpace3d::line(cutBottom.point[npb-1], v);
         }
 
         /* Compute the intersection point of the cut edges */
@@ -846,10 +839,10 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
         for ( i = 1; i < npl/2; i++)
         {
             if ( (CVector3d(cutRight.point[npl-1-i] - pt) * v4) >= 0)
-                CVector3d(cutRight.point[npl-1-i]) = pt;
+                cutRight.point[npl-1-i] = pt;
 
             if ( (CVector3d(cutTop.point[npb-1-i] - pt) * v6) >= 0)
-                CVector3d(cutTop.point[npb-1-i]) = pt;
+                cutTop.point[npb-1-i] = pt;
         }
     }
     else
@@ -857,23 +850,23 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
         if ( v2.norm() > .01)
         {
             v = CVector3d(cutLeft.point[npl-1] - cutLeft.point[npl-2]);
-            l1 = CSubSpace(cutLeft.point[npl-1], v.matrix(), GEOCPP_FROM_BASE);
+            l1 = CSubSpace3d::line(cutLeft.point[npl-1], v);
         }
         else if ( v1.norm() > .01)
         {
             v = CVector3d(cutLeft.point[npl/2] - cutLeft.point[npl/2 -1]);
-            l1 = CSubSpace(cutLeft.point[npl/2], v.matrix(), GEOCPP_FROM_BASE);
+            l1 = CSubSpace3d::line(cutLeft.point[npl/2], v);
         }
 
         if ( v4.norm() > .01)
         {
             v = CVector3d(cutRight.point[npl-1] - cutRight.point[npl-2]);
-            l2 = CSubSpace(cutRight.point[npl-1], v.matrix(), GEOCPP_FROM_BASE);
+            l2 = CSubSpace3d::line(cutRight.point[npl-1], v);
         }
         else if ( v3.norm() > .01)
         {
             v = CVector3d(cutRight.point[npl/2] - cutRight.point[npl/2-1]);
-            l2 = CSubSpace(cutRight.point[npl/2], v.matrix(), GEOCPP_FROM_BASE);
+            l2 = CSubSpace3d::line(cutRight.point[npl/2], v);
         }
 
         /* Compute the intersection point of the 2 side edges */
@@ -895,7 +888,7 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
         for ( i = 1; i < npl/2; i++)
         {
             if ( (CVector3d(cutLeft.point[npl-1-i] - pt) * v2) >= 0 )
-                CVector3d(cutLeft.point[npl-1-i]) = pt;
+                cutLeft.point[npl-1-i] = pt;
         }
 
         /* Adjust the upper right point to be at intersection */
@@ -908,7 +901,7 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
         for ( i = 1; i < npl/2; i++)
         {
             if ( (CVector3d(cutRight.point[npl-1-i] - pt) * v4) >= 0)
-                CVector3d(cutRight.point[npl-1-i]) = pt;
+                cutRight.point[npl-1-i] = pt;
         }
     } // end else top edge is a point
 } //// end addHems ////////////////////////////////////////
