@@ -1,9 +1,7 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Lain
+ * Copyright (C) 1993-2006 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
- * $Id: sailcalc.h,v 1.9 2006/01/25 21:54:01 jeremy_laine Exp $
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -22,7 +20,7 @@
 #ifndef SAILCALC_H
 #define SAILCALC_H
 
-#include "geocpp/vect_geom.h"
+#include "geocpp/geometry.h"
 
 real RoundP( const real &x, const int &p );
 real Atriangle( const real &a, const real &b, const real &c );
