@@ -1,7 +1,6 @@
 /*
  * Copyright (C) 1993-2006 Robert & Jeremy Laine
- * 
- * $Id: sailcutqt.h,v 1.10 2006/01/25 21:54:01 jeremy_laine Exp $
+ * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,7 +23,14 @@
 #include <QApplication>
 #include "prefs.h"
 
+#if QT_VERSION >= 0x040200
+#define HAVE_QDESKTOPSERVICES
+#else
+#undef HAVE_QDESKTOPSERVICES
+#endif
+
 class QTranslator;
+class QUrl;
 
 /**
  *  Class representing a Sailcut application.
@@ -34,7 +40,7 @@ class CSailApp : public QApplication
 public:
     CSailApp(int argc, char* argv[]);
 
-    static QString findHandbook(const QString locale);
+    static QUrl findHandbook(const QString locale);
     void loadTranslation(const QString locale);
     void readPrefs();
     void writePrefs();
