@@ -1,7 +1,6 @@
 /*
  * Copyright (C) 1993-2006 Robert & Jeremy Laine
- *
- * $Id: saildisp.h,v 1.33 2006/01/25 21:54:02 jeremy_laine Exp $
+ * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -84,6 +83,8 @@ protected:
     CRect3d m_lRect;
     /** Viewport rectangle, in device coordinates */
     CRect3d m_vRect;
+    /** Bounding rectangle of the unrotated sail */
+    CRect3d rectBase;
 };
 
 
