@@ -1,9 +1,7 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Lain
+ * Copyright (C) 1993-2006 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
- * $Id: sailwriter-hand.h,v 1.3 2006/01/25 21:54:02 jeremy_laine Exp $
- * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -28,13 +26,19 @@
 /** This class allows you to write a developed sail by using
  *  the deviation of the edge from the straight line instead
  *  of using absolute coordinates to a TXT file.
- *
- *  @see CSailWriterHand
  */
-class CSailWriterHand : public TxtWriterTempl<CSail>
+class CSailHandWriter : public CSailTxtWriter
 {
 public:
-    CSailWriterHand(const CSail &sail);
+    /** The constructor.
+     *
+     * @param sail the sail to write
+     */
+    CSailHandWriter(const CSail &sail)
+            : CSailTxtWriter(sail)
+    {}
+    ;
+
     virtual void write(const QString &filename);
 };
 
