@@ -1,7 +1,6 @@
 /*
  * Copyright (C) 1993-2006 Robert & Jeremy Laine
- * 
- * $Id: sailwriter-xml.h,v 1.8 2006/01/25 21:54:02 jeremy_laine Exp $
+ * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,6 +32,8 @@ template <class objtype>
 class XmlWriterTempl : public CFileWriter
 {
 protected :
+    /** the object's name */
+    QString _name;
     /** the object to write */
     objtype _obj;
 
@@ -46,12 +47,7 @@ public:
      */
     XmlWriterTempl(const objtype &obj, const QString &name,
                    const QString ext = ".xml", const QString desc = "XML files")
-            : CFileWriter(name, ext, desc), _obj(obj)
-    {}
-    ;
-
-    /** The destructor. */
-    virtual ~XmlWriterTempl()
+            : CFileWriter(ext, desc), _name(name), _obj(obj)
     {}
     ;
 
