@@ -1,4 +1,5 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS><TS version="1.1" language="en_GB">
 <context>
     <name>CFileIO</name>
     <message>
@@ -23,17 +24,13 @@
 </context>
 <context>
     <name>CFormDef</name>
-    <message>
-        <source>Sailcut</source>
-        <translation type="obsolete">Sailcut</translation>
-    </message>
     <message>
         <source>Sail corners coordinates</source>
-        <translation type="unfinished"></translation>
+        <translation>Vela circonda coordinate</translation>
     </message>
     <message>
         <source>tack</source>
-        <translation type="unfinished"></translation>
+        <translation>chiodino</translation>
     </message>
     <message>
         <source>clew</source>
@@ -41,15 +38,15 @@
     </message>
     <message>
         <source>head</source>
-        <translation type="unfinished"></translation>
+        <translation>testa</translation>
     </message>
     <message>
         <source>peak</source>
-        <translation type="unfinished"></translation>
+        <translation>vetta</translation>
     </message>
     <message>
         <source>IRC width measurements</source>
-        <translation type="unfinished"></translation>
+        <translation>IRC misure di ampiezza</translation>
     </message>
 </context>
 <context>
@@ -255,7 +252,7 @@
         <translation>Calcola</translation>
     </message>
     <message>
-        <source>Sail ID </source>
+        <source>Sail ID</source>
         <translation>Nome della vela</translation>
     </message>
     <message>
@@ -353,8 +350,8 @@
         <translation>&amp;Aiuto</translation>
     </message>
     <message>
-        <source>About Sailcut</source>
-        <translation>A proposito di Sailcut</translation>
+        <source>About Sailcut CAD</source>
+        <translation>A proposito di Sailcut CAD</translation>
     </message>
     <message>
         <source>error</source>
@@ -362,15 +359,15 @@
     </message>
     <message>
         <source>There was an error writing to the selected file</source>
-        <translation>Errore di scrittura sul file selezionato.</translation>
+        <translation>Errore di scrittura sul file selezionato</translation>
     </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>A proposito di &amp;Qt</translation>
     </message>
     <message>
-        <source>About &amp;Sailcut</source>
-        <translation>A proposito di &amp;Sailcut</translation>
+        <source>About &amp;Sailcut CAD</source>
+        <translation>A proposito di &amp;Sailcut CAD</translation>
     </message>
     <message>
         <source>Language</source>
@@ -393,8 +390,8 @@
         <translation>Esporta &amp;svilupppo</translation>
     </message>
     <message>
-        <source>Sailcut &amp;Handbook</source>
-        <translation>Manuale &amp;Sailcut</translation>
+        <source>Sailcut CAD &amp;Handbook</source>
+        <translation>Manuale &amp;Sailcut CAD</translation>
     </message>
     <message>
         <source>shaded view</source>
@@ -452,13 +449,9 @@
         <source>&amp;Print</source>
         <translation>&amp;Stampa</translation>
     </message>
-    <message>
-        <source>Sailcut data sheet</source>
-        <translation>Scheda dati Sailcut</translation>
-    </message>
     <message>
         <source>Sail type</source>
-        <translation>Tipo vela</translation>
+        <translation type="obsolete">Tipo vela</translation>
     </message>
     <message>
         <source>Main sail</source>
@@ -466,39 +459,39 @@
     </message>
     <message>
         <source>Jib</source>
-        <translation>Fiocco</translation>
+        <translation type="obsolete">Fiocco</translation>
     </message>
     <message>
         <source>Sail layout</source>
-        <translation>Taglio vela</translation>
+        <translation type="obsolete">Taglio vela</translation>
     </message>
     <message>
         <source>Cross Cut</source>
-        <translation>Taglio cross-cut</translation>
+        <translation type="obsolete">Taglio cross-cut</translation>
     </message>
     <message>
         <source>Horizontal Cut</source>
-        <translation>Taglio orizzontale</translation>
+        <translation type="obsolete">Taglio orizzontale</translation>
     </message>
     <message>
         <source>Radial Cut</source>
-        <translation>Taglio radiale</translation>
+        <translation type="obsolete">Taglio radiale</translation>
     </message>
     <message>
         <source>Twist Foot Cut</source>
-        <translation>Taglio twist foot</translation>
+        <translation type="obsolete">Taglio twist foot</translation>
     </message>
     <message>
         <source>Vertical Cut</source>
-        <translation>Taglio verticale</translation>
+        <translation type="obsolete">Taglio verticale</translation>
     </message>
     <message>
         <source>Mitre Cut</source>
-        <translation>Taglio a spina di pesce</translation>
+        <translation type="obsolete">Taglio a spina di pesce</translation>
     </message>
     <message>
         <source> sections,   </source>
-        <translation> sezioni,   </translation>
+        <translation type="obsolete"> sezioni,   </translation>
     </message>
     <message>
         <source> head gores.</source>
@@ -506,115 +499,115 @@
     </message>
     <message>
         <source>Rig </source>
-        <translation>Attrezzatura </translation>
+        <translation type="obsolete">Attrezzatura </translation>
     </message>
     <message>
         <source>Boat LOA</source>
-        <translation>Lunghezza della barca</translation>
+        <translation type="obsolete">Lunghezza della barca</translation>
     </message>
     <message>
         <source>Fore triangle hoist I</source>
-        <translation>Altezza I del triangolo di prua</translation>
+        <translation type="obsolete">Altezza I del triangolo di prua</translation>
     </message>
     <message>
         <source>Fore triangle base J</source>
-        <translation>Base J del triangolo di prua</translation>
+        <translation type="obsolete">Base J del triangolo di prua</translation>
     </message>
     <message>
         <source>Tack position X</source>
-        <translation>Posizione X del punto di mura</translation>
+        <translation type="obsolete">Posizione X del punto di mura</translation>
     </message>
     <message>
         <source>Tack height Y</source>
-        <translation>Altezza Y del punto di mura</translation>
+        <translation type="obsolete">Altezza Y del punto di mura</translation>
     </message>
     <message>
         <source>Sail dimensions</source>
-        <translation>Dimensioni della vela</translation>
+        <translation type="obsolete">Dimensioni della vela</translation>
     </message>
     <message>
         <source>Luff length</source>
-        <translation>Lunghezza del ghindante</translation>
+        <translation type="obsolete">Lunghezza del ghindante</translation>
     </message>
     <message>
         <source>Gaff angle wrt luff</source>
-        <translation>Angolo tra picco e ghindante</translation>
+        <translation type="obsolete">Angolo tra picco e ghindante</translation>
     </message>
     <message>
         <source>Gaff length</source>
-        <translation>Lunghezza del picco</translation>
+        <translation type="obsolete">Lunghezza del picco</translation>
     </message>
     <message>
         <source>Foot length</source>
-        <translation>Lunghezza della base</translation>
+        <translation type="obsolete">Lunghezza della base</translation>
     </message>
     <message>
         <source>Leech length</source>
-        <translation>Lunghezza della balumina</translation>
+        <translation type="obsolete">Lunghezza della balumina</translation>
     </message>
     <message>
         <source>Shape of edges</source>
-        <translation>Forma dei bordi</translation>
+        <translation type="obsolete">Forma dei bordi</translation>
     </message>
     <message>
         <source>Luff round</source>
-        <translation>Allunamento del ghindante</translation>
+        <translation type="obsolete">Allunamento del ghindante</translation>
     </message>
     <message>
         <source>Gaff round</source>
-        <translation>Allunamento del picco</translation>
+        <translation type="obsolete">Allunamento del picco</translation>
     </message>
     <message>
         <source>Leech round</source>
-        <translation>Allunamento della balumina</translation>
+        <translation type="obsolete">Allunamento della balumina</translation>
     </message>
     <message>
         <source>Foot round</source>
-        <translation>Allunamento della base</translation>
+        <translation type="obsolete">Allunamento della base</translation>
     </message>
     <message>
         <source>Luff round position</source>
-        <translation>Posizione allunamento ghindante</translation>
+        <translation type="obsolete">Posizione allunamento ghindante</translation>
     </message>
     <message>
         <source>Gaff round position</source>
-        <translation>Posizione allunamento picco</translation>
+        <translation type="obsolete">Posizione allunamento picco</translation>
     </message>
     <message>
         <source>Leech round position</source>
-        <translation>Posizione allunamento balumina</translation>
+        <translation type="obsolete">Posizione allunamento balumina</translation>
     </message>
     <message>
         <source>Foot round position</source>
-        <translation>Posizione allunamento base</translation>
+        <translation type="obsolete">Posizione allunamento base</translation>
     </message>
     <message>
         <source>Sail settings</source>
-        <translation>Regolazioni vela</translation>
+        <translation type="obsolete">Regolazioni vela</translation>
     </message>
     <message>
         <source>Twist angle</source>
-        <translation>Angolo di svergolamento</translation>
+        <translation type="obsolete">Angolo di svergolamento</translation>
     </message>
     <message>
         <source>Sheeting angle</source>
-        <translation>Angolo caduta vela</translation>
+        <translation type="obsolete">Angolo caduta vela</translation>
     </message>
     <message>
         <source>Cloth seams and hems</source>
-        <translation>Vivagni e vaine tessuto vela</translation>
+        <translation type="obsolete">Vivagni e vaine tessuto vela</translation>
     </message>
     <message>
         <source>Cloth width</source>
-        <translation>Larghezza del tessuto vela</translation>
+        <translation type="obsolete">Larghezza del tessuto vela</translation>
     </message>
     <message>
         <source>Seams width</source>
-        <translation>Larghezza vivagni</translation>
+        <translation type="obsolete">Larghezza vivagni</translation>
     </message>
     <message>
         <source>Leech hem width</source>
-        <translation>Larghezza vaina balumina</translation>
+        <translation type="obsolete">Larghezza vaina balumina</translation>
     </message>
     <message>
         <source>Other hems width</source>
@@ -622,35 +615,35 @@
     </message>
     <message>
         <source>Sail mould</source>
-        <translation>Profilo della vela</translation>
+        <translation type="obsolete">Profilo della vela</translation>
     </message>
     <message>
         <source>Luff factor</source>
-        <translation>Fattore ghindante</translation>
+        <translation type="obsolete">Fattore ghindante</translation>
     </message>
     <message>
         <source>Depth</source>
-        <translation>Profondita&apos;</translation>
+        <translation type="obsolete">Profondita&apos;</translation>
     </message>
     <message>
         <source>Leech factor</source>
-        <translation>Fattore balumina</translation>
+        <translation type="obsolete">Fattore balumina</translation>
     </message>
     <message>
         <source>Top profile</source>
-        <translation>Profilo superiore</translation>
+        <translation type="obsolete">Profilo superiore</translation>
     </message>
     <message>
         <source>Mid profile at h = </source>
-        <translation>Profilo mediano ad &quot;h&quot;</translation>
+        <translation type="obsolete">Profilo mediano ad &quot;h&quot;</translation>
     </message>
     <message>
         <source>Bottom profile</source>
-        <translation>Profilo inferiore</translation>
+        <translation type="obsolete">Profilo inferiore</translation>
     </message>
     <message>
         <source>Mast/Luff rake</source>
-        <translation>Inclinazione albero/ghindante</translation>
+        <translation type="obsolete">Inclinazione albero/ghindante</translation>
     </message>
     <message>
         <source>E&amp;xport 3D sail</source>
@@ -658,27 +651,11 @@
     </message>
     <message>
         <source>Mainsail</source>
-        <translation>Randa</translation>
-    </message>
-    <message>
-        <source> head gores,   </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Other hem width</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Wing</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source> luff gores.</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Randa</translation>
     </message>
     <message>
         <source>deg</source>
-        <translation>deg</translation>
+        <translation type="obsolete">deg</translation>
     </message>
     <message>
         <source>to &amp;Hand-plotting format</source>
@@ -817,6 +794,221 @@
         <translation type="obsolete">Il supporto OpenGL non e&apos; disponibile su questo sistema.</translation>
     </message>
 </context>
+<context>
+    <name>CSailPrinter</name>
+    <message>
+        <source>Sailcut CAD data sheet</source>
+        <translation>Scheda dati Sailcut CAD</translation>
+    </message>
+    <message>
+        <source>Mainsail</source>
+        <translation>Randa</translation>
+    </message>
+    <message>
+        <source>Jib</source>
+        <translation>Fiocco</translation>
+    </message>
+    <message>
+        <source>Wing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>deg</source>
+        <translation>deg</translation>
+    </message>
+    <message>
+        <source>Sail type</source>
+        <translation>Tipo vela</translation>
+    </message>
+    <message>
+        <source>Cross Cut</source>
+        <translation>Taglio cross-cut</translation>
+    </message>
+    <message>
+        <source>Horizontal Cut</source>
+        <translation>Taglio orizzontale</translation>
+    </message>
+    <message>
+        <source>Radial Cut</source>
+        <translation>Taglio radiale</translation>
+    </message>
+    <message>
+        <source>sections</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>head gores</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>luff gores</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Twist Foot Cut</source>
+        <translation>Taglio twist foot</translation>
+    </message>
+    <message>
+        <source>Vertical Cut</source>
+        <translation>Taglio verticale</translation>
+    </message>
+    <message>
+        <source>Mitre Cut</source>
+        <translation>Taglio a spina di pesce</translation>
+    </message>
+    <message>
+        <source>Sail layout</source>
+        <translation>Taglio vela</translation>
+    </message>
+    <message>
+        <source>Rig</source>
+        <translation>Attrezzatura</translation>
+    </message>
+    <message>
+        <source>Boat LOA</source>
+        <translation>Lunghezza della barca</translation>
+    </message>
+    <message>
+        <source>Mast/Luff rake</source>
+        <translation>Inclinazione albero/ghindante</translation>
+    </message>
+    <message>
+        <source>Tack position X</source>
+        <translation>Posizione X del punto di mura</translation>
+    </message>
+    <message>
+        <source>Tack height Y</source>
+        <translation>Altezza Y del punto di mura</translation>
+    </message>
+    <message>
+        <source>Fore triangle hoist I</source>
+        <translation>Altezza I del triangolo di prua</translation>
+    </message>
+    <message>
+        <source>Fore triangle base J</source>
+        <translation>Base J del triangolo di prua</translation>
+    </message>
+    <message>
+        <source>Sail dimensions</source>
+        <translation>Dimensioni della vela</translation>
+    </message>
+    <message>
+        <source>Luff length</source>
+        <translation>Lunghezza del ghindante</translation>
+    </message>
+    <message>
+        <source>Foot length</source>
+        <translation>Lunghezza della base</translation>
+    </message>
+    <message>
+        <source>Leech length</source>
+        <translation>Lunghezza della balumina</translation>
+    </message>
+    <message>
+        <source>Gaff length</source>
+        <translation>Lunghezza del picco</translation>
+    </message>
+    <message>
+        <source>Gaff angle wrt luff</source>
+        <translation>Angolo tra picco e ghindante</translation>
+    </message>
+    <message>
+        <source>Shape of edges</source>
+        <translation>Forma dei bordi</translation>
+    </message>
+    <message>
+        <source>Luff round</source>
+        <translation>Allunamento del ghindante</translation>
+    </message>
+    <message>
+        <source>Luff round position</source>
+        <translation>Posizione allunamento ghindante</translation>
+    </message>
+    <message>
+        <source>Foot round</source>
+        <translation>Allunamento della base</translation>
+    </message>
+    <message>
+        <source>Foot round position</source>
+        <translation>Posizione allunamento base</translation>
+    </message>
+    <message>
+        <source>Leech round</source>
+        <translation>Allunamento della balumina</translation>
+    </message>
+    <message>
+        <source>Leech round position</source>
+        <translation>Posizione allunamento balumina</translation>
+    </message>
+    <message>
+        <source>Gaff round</source>
+        <translation>Allunamento del picco</translation>
+    </message>
+    <message>
+        <source>Gaff round position</source>
+        <translation>Posizione allunamento picco</translation>
+    </message>
+    <message>
+        <source>Sail settings</source>
+        <translation>Regolazioni vela</translation>
+    </message>
+    <message>
+        <source>Twist angle</source>
+        <translation>Angolo di svergolamento</translation>
+    </message>
+    <message>
+        <source>Sheeting angle</source>
+        <translation>Angolo caduta vela</translation>
+    </message>
+    <message>
+        <source>Cloth seams and hems</source>
+        <translation>Vivagni e vaine tessuto vela</translation>
+    </message>
+    <message>
+        <source>Cloth width</source>
+        <translation>Larghezza del tessuto vela</translation>
+    </message>
+    <message>
+        <source>Seams width</source>
+        <translation>Larghezza vivagni</translation>
+    </message>
+    <message>
+        <source>Leech hem width</source>
+        <translation>Larghezza vaina balumina</translation>
+    </message>
+    <message>
+        <source>Other hem width</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sail mould</source>
+        <translation>Profilo della vela</translation>
+    </message>
+    <message>
+        <source>Luff factor</source>
+        <translation>Fattore ghindante</translation>
+    </message>
+    <message>
+        <source>Depth</source>
+        <translation>Profondita&apos;</translation>
+    </message>
+    <message>
+        <source>Leech factor</source>
+        <translation>Fattore balumina</translation>
+    </message>
+    <message>
+        <source>Top profile</source>
+        <translation>Profilo superiore</translation>
+    </message>
+    <message>
+        <source>Mid profile at h = </source>
+        <translation>Profilo mediano ad &quot;h&quot;</translation>
+    </message>
+    <message>
+        <source>Bottom profile</source>
+        <translation>Profilo inferiore</translation>
+    </message>
+</context>
 <context>
     <name>CSailViewerPanel</name>
     <message>
@@ -874,6 +1066,14 @@
         <source>Leech shape</source>
         <translation>Forma balumina</translation>
     </message>
+    <message>
+        <source>degrees</source>
+        <translation>gradi</translation>
+    </message>
+    <message>
+        <source>cord</source>
+        <translation>corda</translation>
+    </message>
 </context>
 <context>
     <name>XmlReaderTempl</name>
